@@ -9,9 +9,11 @@
 (custom-add-loads 'crontab '("crontab"))
 (custom-add-loads 'scribe '("scribe"))
 (custom-add-loads 'auto-insert '("autoinsert"))
+(custom-add-loads 'flyspell '("flyspell"))
 (custom-add-loads 'languages '("crontab" "winmgr-mode" "xrdb-mode"))
 (custom-add-loads 'fill '("filladapt"))
 (custom-add-loads 'folding '("folding"))
+(custom-add-loads 'processes '("flyspell"))
 (custom-add-loads 'wp '("scribe"))
 (custom-add-loads 'whitespace '("whitespace-mode"))
 (custom-add-loads 'matching '("whitespace-mode"))
