@@ -375,6 +375,7 @@ END. OLD-LEN isn't used, but provided from the after-change hook."
     (whitespace-dehighlight-region beg end)
     (whitespace-highlight-region beg end)))
 
+;;;###autoload
 (defun whitespace-mode (&optional arg)
   "Toggle whitespace mode.
 With arg, turn whitespace mode on iff arg is positive.
@@ -526,7 +527,7 @@ the region from (point) - (window-heigh) to (point) + (window-heigh)."
 static char * whitespace[] = {
 \"28 28 4 1\",
 \" 	c Gray75 s backgroundToolBarColor\",
-\".	c black\",
+\".	c black s foregroundToolBarColor\",
 \"X	c Gray60\",
 \"o	c white\",
 \"                            \",
